@@ -536,5 +536,105 @@ def get_python_module_partials(
     return partialsDictionary
 
 
+## LAST MODIFIED : July 29, 2013
+## CREATED : July 29, 2013
+## AUTHOR : DRYX
+def get_recursive_list_of_directory_contents(
+        log,
+        baseFolderPath,
+        whatToList="all"
+    ):
+    """list directory contents recursively.
+
+    Options to list only files or only directories.
+
+    **Key Arguments:**
+        - ``log`` -- logger
+        - ``baseFolderPath`` -- path to the base folder to list contained files and folders recursively
+        - ``whatToList`` -- list files only, durectories only or all [ "files" | "dirs" | "all" ]
+
+    **Return:**
+        - ``matchedPathList`` -- the matched paths
+    """
+    ################ > IMPORTS ################
+    ## STANDARD LIB ##
+    import os
+    ## THIRD PARTY ##
+    ## LOCAL APPLICATION ##
+
+    log.info('starting the ``get_recursive_list_of_directory_contents`` function')
+
+    ## VARIABLES ##
+    matchedPathList = []
+    parentDirectoryList = [baseFolderPath,]
+
+    count = 0
+    while os.listdir(baseFolderPath) and count < 20:
+        count += 1
+
+        while len(parentDirectoryList) != 0:
+            childDirList = []
+            for parentDir in parentDirectoryList:
+                thisDirList = os.listdir(parentDir)
+                for d in thisDirList:
+                    fullPath = os.path.join(parentDir, d)
+
+                    if whatToList is "all":
+                        matched = True
+                    elif whatToList is "dirs":
+                        matched = os.path.isdir(fullPath)
+                    elif whatToList is "files":
+                        matched = os.path.isfile(fullPath)
+                    else:
+                        log.error('cound not list files in %s, `whatToList` variable incorrect: [ "files" | "dirs" | "all" ]' % (baseFolderPath,))
+                        sys.exit(0)
+
+                    if matched:
+                        matchedPathList.append(fullPath)
+
+                    ## UPDATE DIRECTORY LISTING
+                    if os.path.isdir(fullPath):
+                        childDirList.append(fullPath)
+
+                parentDirectoryList = childDirList
+
+    log.info('completed the ``get_recursive_list_of_directory_contents`` function')
+    return matchedPathList
+
+
+## LAST MODIFIED : August 17, 2013
+## CREATED : August 17, 2013
+## AUTHOR : DRYX
+def get_help_for_python_module(
+        pathToModuleFile,
+        log):
+    """print the help for python module
+
+    **Key Arguments:**
+        - ``pathToModuleFile`` -- the path to the python module
+        - ``log`` -- logger
+
+    **Return:**
+        - None
+
+    **Todo**
+        - [ ] when complete, clean get_help_for_python_module function
+        - [ ] when complete add logging
+        - [ ] when complete, decide whether to abstract function to another module
+    """
+    ################ > IMPORTS ################
+    ## STANDARD LIB ##
+    ## THIRD PARTY ##
+    ## LOCAL APPLICATION ##
+
+    log.info('starting the ``get_help_for_python_module`` function')
+    ## VARIABLES ##
+
+    basename = os.path.basename(pathToModuleFile).replace(".py")
+    print basename
+
+    log.info('completed the ``get_help_for_python_module`` function')
+    return None
+
 if __name__ == '__main__':
     main()
